/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
import { createScanner } from './parser/htmlScanner';
import { parse } from './parser/htmlParser';
import { HTMLCompletion } from './services/htmlCompletion';
import { doHover } from './services/htmlHover';
import { format } from './services/htmlFormatter';
import { findDocumentLinks } from './services/htmlLinks';
import { findDocumentHighlights } from './services/htmlHighlighting';
import { findDocumentSymbols } from './services/htmlSymbolsProvider';
import { getFoldingRanges } from './services/htmlFolding';
import { handleCustomDataProviders, HTMLDataProvider } from './languageFacts';
import { getSelectionRanges } from './services/htmlSelectionRange';
export * from './htmlLanguageTypes';
export * from 'vscode-languageserver-types';
export function getLanguageService(options) {
    const htmlCompletion = new HTMLCompletion();
    if (options && options.customDataProviders) {
        handleCustomDataProviders(options.customDataProviders);
    }
    return {
        createScanner,
        parseHTMLDocument: document => parse(document.getText()),
        doComplete: htmlCompletion.doComplete.bind(htmlCompletion),
        setCompletionParticipants: htmlCompletion.setCompletionParticipants.bind(htmlCompletion),
        doHover,
        format,
        findDocumentHighlights,
        findDocumentLinks,
        findDocumentSymbols,
        getFoldingRanges,
        getSelectionRanges,
        doTagComplete: htmlCompletion.doTagComplete.bind(htmlCompletion),
    };
}
export function newHTMLDataProvider(id, customData) {
    return new HTMLDataProvider(id, customData);
}
//# sourceMappingURL=htmlLanguageService.js.map