(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./parser/htmlScanner", "./parser/htmlParser", "./services/htmlCompletion", "./services/htmlHover", "./services/htmlFormatter", "./services/htmlLinks", "./services/htmlHighlighting", "./services/htmlSymbolsProvider", "./services/htmlFolding", "./languageFacts", "./services/htmlSelectionRange", "./htmlLanguageTypes", "vscode-languageserver-types"], factory);
    }
})(function (require, exports) {
    /*---------------------------------------------------------------------------------------------
     *  Copyright (c) Microsoft Corporation. All rights reserved.
     *  Licensed under the MIT License. See License.txt in the project root for license information.
     *--------------------------------------------------------------------------------------------*/
    'use strict';
    function __export(m) {
        for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
    }
    Object.defineProperty(exports, "__esModule", { value: true });
    const htmlScanner_1 = require("./parser/htmlScanner");
    const htmlParser_1 = require("./parser/htmlParser");
    const htmlCompletion_1 = require("./services/htmlCompletion");
    const htmlHover_1 = require("./services/htmlHover");
    const htmlFormatter_1 = require("./services/htmlFormatter");
    const htmlLinks_1 = require("./services/htmlLinks");
    const htmlHighlighting_1 = require("./services/htmlHighlighting");
    const htmlSymbolsProvider_1 = require("./services/htmlSymbolsProvider");
    const htmlFolding_1 = require("./services/htmlFolding");
    const languageFacts_1 = require("./languageFacts");
    const htmlSelectionRange_1 = require("./services/htmlSelectionRange");
    __export(require("./htmlLanguageTypes"));
    __export(require("vscode-languageserver-types"));
    function getLanguageService(options) {
        const htmlCompletion = new htmlCompletion_1.HTMLCompletion();
        if (options && options.customDataProviders) {
            languageFacts_1.handleCustomDataProviders(options.customDataProviders);
        }
        return {
            createScanner: htmlScanner_1.createScanner,
            parseHTMLDocument: document => htmlParser_1.parse(document.getText()),
            doComplete: htmlCompletion.doComplete.bind(htmlCompletion),
            setCompletionParticipants: htmlCompletion.setCompletionParticipants.bind(htmlCompletion),
            doHover: htmlHover_1.doHover,
            format: htmlFormatter_1.format,
            findDocumentHighlights: htmlHighlighting_1.findDocumentHighlights,
            findDocumentLinks: htmlLinks_1.findDocumentLinks,
            findDocumentSymbols: htmlSymbolsProvider_1.findDocumentSymbols,
            getFoldingRanges: htmlFolding_1.getFoldingRanges,
            getSelectionRanges: htmlSelectionRange_1.getSelectionRanges,
            doTagComplete: htmlCompletion.doTagComplete.bind(htmlCompletion),
        };
    }
    exports.getLanguageService = getLanguageService;
    function newHTMLDataProvider(id, customData) {
        return new languageFacts_1.HTMLDataProvider(id, customData);
    }
    exports.newHTMLDataProvider = newHTMLDataProvider;
});
//# sourceMappingURL=htmlLanguageService.js.map