(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    /*---------------------------------------------------------------------------------------------
     *  Copyright (c) Microsoft Corporation. All rights reserved.
     *  Licensed under the MIT License. See License.txt in the project root for license information.
     *--------------------------------------------------------------------------------------------*/
    'use strict';
    Object.defineProperty(exports, "__esModule", { value: true });
    class HTMLDataProvider {
        /**
         * Currently, unversioned data uses the V1 implementation
         * In the future when the provider handles multiple versions of HTML custom data,
         * use the latest implementation for unversioned data
         */
        constructor(id, customData) {
            this.id = id;
            this._tags = [];
            this._tagMap = {};
            this._attributeMap = {};
            this._valueSetMap = {};
            this._tags = customData.tags || [];
            this._globalAttributes = customData.globalAttributes || [];
            this._tags.forEach(t => {
                this._tagMap[t.name] = t;
                if (t.attributes) {
                    t.attributes.forEach(a => {
                        this._attributeMap[a.name] = a;
                    });
                }
            });
            this._globalAttributes.forEach(a => {
                this._attributeMap[a.name] = a;
            });
            if (customData.valueSets) {
                customData.valueSets.forEach(vs => {
                    this._valueSetMap[vs.name] = vs.values;
                });
            }
        }
        isApplicable() {
            return true;
        }
        getId() {
            return this.id;
        }
        provideTags() {
            return this._tags;
        }
        provideAttributes(tag) {
            const attributes = [];
            const processAttribute = (a) => {
                attributes.push({
                    name: a.name,
                    description: a.description,
                    valueSet: a.valueSet
                });
            };
            if (this._tagMap[tag]) {
                this._tagMap[tag].attributes.forEach(a => {
                    processAttribute(a);
                });
            }
            this._globalAttributes.forEach(ga => {
                processAttribute(ga);
            });
            return attributes;
        }
        provideValues(tag, attribute) {
            const values = [];
            const processAttributes = (attributes) => {
                attributes.forEach(a => {
                    if (a.name === attribute) {
                        if (a.values) {
                            a.values.forEach(v => {
                                values.push(v);
                            });
                        }
                        if (a.valueSet) {
                            if (this._valueSetMap[a.valueSet]) {
                                this._valueSetMap[a.valueSet].forEach(v => {
                                    values.push(v);
                                });
                            }
                        }
                    }
                });
            };
            if (!this._tagMap[tag]) {
                return [];
            }
            processAttributes(this._tagMap[tag].attributes);
            processAttributes(this._globalAttributes);
            return values;
        }
    }
    exports.HTMLDataProvider = HTMLDataProvider;
});
//# sourceMappingURL=dataProvider.js.map